==> 0.0.1.tar.gz: lib/bloc/rewards_module/pages/permitted_staff_members.dart <==


import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:loyalty_foop/bloc/cubits/cubit_main.dart';
import 'package:loyalty_foop/utils/custom_tab_maker.dart';

import 'package:shared_preferences/shared_preferences.dart';
import 'package:loyalty_foop/utils/colors.dart';
import 'package:loyalty_foop/utils/custom_app_bar.dart';
import 'package:loyalty_foop/utils/hexColors.dart';
import 'package:loyalty_foop/utils/localization.dart';
import 'package:loyalty_foop/utils/locator.dart';

import 'member_page.dart';
import 'package:loyalty_foop/utils/text_styling.dart';

import 'add_team_member.dart';

// ignore: must_be_immutable
class PermittedStaffMembers extends StatefulWidget {



  PermittedStaffMembersState createState() => PermittedStaffMembersState();
}

class PermittedStaffMembersState extends State<PermittedStaffMembers>
    with SingleTickerProviderStateMixin {
  List<CustomTabMaker>? list = [];
  late TabController _tabController;
  late TextStyleElements styleElements;
  List<PopupMenuItem>? menuItems;
  SharedPreferences prefs = locator<SharedPreferences>();
  String? ownerType;
  int? ownerId;

  int _currentPosition = 0;
  String? pageTitle;
  late Null Function() callback;
  String? imageUrl;
  List<PopupMenuItem> menuList = [];
  List<Widget> invitePartnerList = [];

  List<Widget> invitePartnerEmployeeList = [];
  String? type;

  bool isMultiSelectEnabled = false;

  @override
  void initState() {
    super.initState();


  }




  @override
  Widget build(BuildContext context) {
    styleElements = TextStyleElements(context);
    return SafeArea(
      child: Scaffold(
        resizeToAvoidBottomInset: true,
        backgroundColor: HexColor(AppColors.appColorBackground),

        appBar: appAppBar().getCustomAppBar(context,
            appBarTitle: AppLocalizations.of(context)!.translate('pr_member'),
            actions: [  InkWell(
              onTap: () {

                Navigator.push(context, MaterialPageRoute(builder: ( context) =>    BlocProvider(
                  create: (_) => CubitMain(),
                  child:     AddMemberPage(),
                ),));




              },
              child: Padding(
                padding: const EdgeInsets.only(left: 12, right: 12.0),
                child: Icon(Icons.add_circle,
                    color: HexColor(AppColors.blueApp)),
              ),
            ),],
            onBackButtonPress: () {
              Navigator.pop(context);
            }),




        // appAppBar().getCustomAppBar(context,
        //     appBarTitle: pageTitle+"'s "+AppLocalizations.of(context).translate('network'),
        //     onBackButtonPress: () {
        //       Navigator.pop(context);
        //     }),
        body:MemberPage(
          callBack: () {

          },
          multiSelectionEnabled: (val) {
            setState(() {
              isMultiSelectEnabled = val;
            });
          },
          key: null,
          type: "contacts", isUserAdmin: true, ownerId: 9,
        ),
      ),
    );
  }


}

==> 0.2.1.tar.gz: lib/bloc/rewards_module/pages/permitted_staff_members.dart <==


import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:loyalty_foop/bloc/cubits/cubit_main.dart';
import 'package:loyalty_foop/utils/custom_tab_maker.dart';

import 'package:shared_preferences/shared_preferences.dart';
import 'package:loyalty_foop/utils/colors.dart';
import 'package:loyalty_foop/utils/custom_app_bar.dart';
import 'package:loyalty_foop/utils/hexColors.dart';
import 'package:loyalty_foop/utils/localization.dart';
import 'package:loyalty_foop/utils/locator.dart';

import 'member_page.dart';
import 'package:loyalty_foop/utils/text_styling.dart';

import 'add_team_member.dart';

// ignore: must_be_immutable
class PermittedStaffMembers extends StatefulWidget {



  PermittedStaffMembersState createState() => PermittedStaffMembersState();
}

class PermittedStaffMembersState extends State<PermittedStaffMembers>
    with SingleTickerProviderStateMixin {
  List<CustomTabMaker>? list = [];
  late TabController _tabController;
  late TextStyleElements styleElements;
  List<PopupMenuItem>? menuItems;
  SharedPreferences prefs = locatorRewards<SharedPreferences>();
  String? ownerType;
  int? ownerId;
  AppLocalizations? localizations=locatorRewards<AppLocalizations>() ;
  int _currentPosition = 0;
  String? pageTitle;
  late Null Function() callback;
  String? imageUrl;
  List<PopupMenuItem> menuList = [];
  List<Widget> invitePartnerList = [];

  List<Widget> invitePartnerEmployeeList = [];
  String? type;

  bool isMultiSelectEnabled = false;

  @override
  void initState() {
    super.initState();


  }




  @override
  Widget build(BuildContext context) {
    styleElements = TextStyleElements(context);
    return SafeArea(
      child: Scaffold(
        resizeToAvoidBottomInset: true,
        backgroundColor: HexColor(AppColors.appColorBackground),

        appBar: appAppBar().getCustomAppBar(context,
            appBarTitle: localizations!.translate('pr_member'),
            actions: [  InkWell(
              onTap: () {

                Navigator.push(context, MaterialPageRoute(builder: ( context) =>    BlocProvider(
                  create: (_) => CubitMain(),
                  child:     AddMemberPage(),
                ),));




              },
              child: Padding(
                padding: const EdgeInsets.only(left: 12, right: 12.0),
                child: Icon(Icons.add_circle,
                    color: HexColor(AppColors.blueApp)),
              ),
            ),],
            onBackButtonPress: () {
              Navigator.pop(context);
            }),




        // appAppBar().getCustomAppBar(context,
        //     appBarTitle: pageTitle+"'s "+AppLocalizations.of(context).translate('network'),
        //     onBackButtonPress: () {
        //       Navigator.pop(context);
        //     }),
        body:MemberPage(
          callBack: () {

          },
          multiSelectionEnabled: (val) {
            setState(() {
              isMultiSelectEnabled = val;
            });
          },
          key: null,
          type: "contacts", isUserAdmin: true, ownerId: 9,
        ),
      ),
    );
  }


}
